@@ -17,7 +17,7 @@ pgc <- function (data,handle.miss=1,is.genotype=0,with.id=0)
            row.i <- data[i,]
            for (j in 1:nloci)
            {
-               .C("g2a_",s=as.integer(row.i[j]),a1=as.integer(a1),a2=as.integer(a2),gid=as.integer(gid))
+               .C("g2a_",s=as.integer(row.i[j]),a1=as.integer(a1),a2=as.integer(a2),gid=as.integer(gid),PACKAGE="gap")
                data[i,2*j-1] <- a1
                data[i,2*j] <- a2
            }
@@ -33,7 +33,7 @@ pgc <- function (data,handle.miss=1,is.genotype=0,with.id=0)
     gret <- matrix(array(0,nobs*nloci2),nrow=nobs)
     z <- .C("pgc",gdata=as.integer(data),handlemiss=as.integer(handle.miss),nobs=as.integer(nobs),nloci=as.integer(nloci),
             alleles=as.integer(alleles), wt=as.integer(wt),gret=as.integer(gret),
-            withid=as.integer(with.id),idsave=as.double(idsave),obscom=as.integer(obscom))
+            withid=as.integer(with.id),idsave=as.double(idsave),obscom=as.integer(obscom),PACKAGE="gap")
     subset <- 1:(z$obscom)
     gret <- matrix(z$gret,nrow=nloci2)[,subset]
     if (with.id) list(cdata=t(gret),obscom=z$obscom,idsave=z$idsave[subset],wt=z$wt[subset])
